@@ -1,7 +1,8 @@
-/* aide, Advanced Intrusion Detection Environment
+/*
+ * AIDE (Advanced Intrusion Detection Environment)
  *
- * Copyright (C) 1999,2000,2001,2002 Rami Lehti, Pablo Virolainen
- * $Header$
+ * Copyright (C) 1999-2002, 2019-2021 Rami Lehti, Pablo Virolainen,
+ *               Hannes von Haugwitz
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -13,15 +14,16 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
  
 #ifndef _BE_H_INCLUDED
 #define _BE_H_INCLUDED
-#include "db_config.h"
+#include <stdbool.h>
+#include "url.h"
 
-FILE* be_init(int inout,url_t* u,int iszipped);
+void* be_init(bool ,url_t*, bool, bool, int, char*, char*);
 
 #endif /* _BE_H_INCLUDED */
