@@ -1,8 +1,8 @@
-/* aide, Advanced Intrusion Detection Environment
+/*
+ * AIDE (Advanced Intrusion Detection Environment)
  *
- * Copyright (C) 1999-2002,2004,2005,2013,2016 Rami Lehti, Pablo Virolainen,
- * Richard van den Berg, Hannes von Haugwitz
- * $Header$
+ * Copyright (C) 1999-2002, 2004-2005, 2013, 2016, 2020 Rami Lehti,
+ *               Pablo Virolainen, Richard van den Berg, Hannes von Haugwitz
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -14,20 +14,30 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef _DB_H_INCLUDED
 #define _DB_H_INCLUDED
 
 #include <stdio.h>
+#include <stdbool.h>
 #include "db_config.h"
 
-int db_init(int);
+typedef enum {
+    DB_TYPE_IN,
+    DB_TYPE_OUT,
+    DB_TYPE_NEW,
+} DB_TYPE;
 
-db_line* db_readline(int);
+byte* base64tobyte(char*, int, size_t *);
+time_t base64totime_t(char*, database*, const char*);
+
+int db_init(database*, bool, bool);
+
+db_line* db_readline(database*);
 
 int db_writespec(db_config*);
 
@@ -37,9 +47,6 @@ void db_close();
 
 void free_db_line(db_line* dl);
 
-extern const char* db_names[];
-extern const int db_value[];
-
 #define DB_OLD            (1<<0)
 #define DB_WRITE          (1<<1)
 #define DB_NEW            (1<<2)
