@@ -1,7 +1,8 @@
-/* aide, Advanced Intrusion Detection Environment
+/*
+ * AIDE (Advanced Intrusion Detection Environment)
  *
- * Copyright (C) 1999,2000,2001,2002 Rami Lehti, Pablo Virolainen
- * $Header: /cvsroot/aide/aide/include/db_disk.h,v 1.1.1.1 2003/01/16 10:37:34 rammer Exp $
+ * Copyright (C) 1999-2002, 2011, 2021 Rami Lehti, Pablo Virolainen,
+ *               Hannes von Haugwitz
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -13,20 +14,18 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef _DB_DISK_H_INCLUDED
 #define _DB_DISK_H_INCLUDED
 
 #include "db.h"
+#include <stdbool.h>
 
-db_line* db_readline_disk(int);
-int db_writespec_disk(db_config*);
-int db_writeline_disk(db_line* line,db_config* conf);
-int db_close_disk(db_config* conf);
+db_line* db_readline_disk(bool);
 int db_disk_init(void);
 
 #endif
