@@ -1,7 +1,8 @@
-/* aide, Advanced Intrusion Detection Environment
+/*
+ * AIDE (Advanced Intrusion Detection Environment)
  *
- * Copyright (C) 1999,2000,2001,2002 Rami Lehti,Pablo Virolainen
- * $Header$
+ * Copyright (C) 1999-2002, 2010 Rami Lehti, Pablo Virolainen,
+ *               Hannes von Haugwitz
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -13,9 +14,9 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef _LIST_H_INCLUDED
@@ -42,6 +43,7 @@ typedef struct list_header{
   
 }list_header;
 
+list* list_sorted_insert(list* listp, void* data, int (*compare) (const void*, const void*));
 
 list* list_append(list* listp,void*data);
 
